@@ -13,6 +13,9 @@
 /* Define this if program can query MITSHM extension */
 #undef HAVE_SHMQUERY
 
+/* Define for the XFree86 X server */
+#undef HAVE_XF86VIDMODE
+
 /* Define this if you have the readline library */
 #undef HAVE_READLINE
 
@@ -32,12 +35,16 @@
 /* Define if sound driver is SUN */
 #undef SUN_SOUND
 
+/* Define if sound driver is IRIX */
+#undef IRIX_SOUND
+
+/* Define if you want to use PC speaker sound */
+#undef PCSPEAKER_SOUND
+
+/* Define if you want to use the Linux joystick driver */
+#undef LINUX_JOYSTICK
+
 /* Define this to use the inline intel assembly sections */
 #undef I386_ASM
 
-/* Define this to use an alternative way of passing the z80 processor
-   data to the z80 instruction emulation functions. May make emulation
-   faster on some machines, but not on intel, and sparc. */
-#undef PROCP
-
 @TOP@
