@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 1996-1998 Szeredi Miklos
+ * Copyright (C) 1996-2004 Szeredi Miklos
  * Email: mszeredi@inf.bme.hu
  *
  * This program is free software; you can redistribute it and/or modify
@@ -30,9 +30,10 @@ extern char *spcf_init_tapefile;
 extern int   spcf_init_tapefile_type;
 
 extern void spcf_pre_check_options(int argc, char *argv[]);
-extern int  spcf_read_conf_file(const char *filename);
+extern int  spcf_read_config();
 extern void spcf_read_command_line(int argc, char *argv[]);
 extern void spcf_read_xresources(void);
-extern int  spcf_find_file_type(char *filename, int *ftp, int *ftsubp);
+extern int  spcf_find_file(const char *fname, char *fpath, 
+                           int *ftp, int *ftsubp);
 
 #endif /* SPCONF_H */
