@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 1996-1998 Szeredi Miklos
+ * Copyright (C) 1996-2004 Szeredi Miklos
  * Email: mszeredi@inf.bme.hu
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,6 +22,8 @@
 #define SPMAIN_H
 
 extern void check_params(int argc, char *argv[]);
-extern void start_spectemu(int argc, char *argv[]);
+extern void start_spectemu();
+extern void spma_init_privileged(void);
+extern void spma_lose_privs(void);
 
 #endif /* SPMAIN_H */
