@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 1996-1998 Szeredi Miklos
+ * Copyright (C) 1996-2004 Szeredi Miklos
  * Email: mszeredi@inf.bme.hu
  *
  * This program is free software; you can redistribute it and/or modify
@@ -25,17 +25,18 @@
 
 int main(int argc, char *argv[])
 {
-  sp_init_vga();
+    spma_init_privileged();
+    sp_init_vga();
 
-  spcf_pre_check_options(argc, argv);
+    spcf_pre_check_options(argc, argv);
 
-  check_params(argc, argv);
-  sp_init();
+    check_params(argc, argv);
+    sp_init();
 
-  start_spectemu(argc, argv);
-  /* This function DOES NOT return */
+    start_spectemu();
+    /* This function DOES NOT return */
 
-  return 0;
+    return 0;
 }
 
 
