@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 1996-1998 Szeredi Miklos
+ * Copyright (C) 1996-2004 Szeredi Miklos
  * Email: mszeredi@inf.bme.hu
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,6 +26,7 @@
 typedef unsigned long pixt;
 
 extern Window xsp_win;
+extern Window top_win;
 extern Display *xsp_disp;
 extern int xsp_scr;
 extern Colormap xsp_cmap;
@@ -35,7 +36,9 @@ extern unsigned xsp_depth;
 extern unsigned long xsp_colors[];
 
 extern void init_x_scr(aX_default_resources* defres,
-		       int *argc, char *argv[]);
+                       int *argc, char *argv[]);
+
+extern void init_xutils(void);
 extern int allocate_colors(void);
 extern void spxs_init_color(void);
 
