@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 1996-1998 Szeredi Miklos
+ * Copyright (C) 1996-2004 Szeredi Miklos
  * Email: mszeredi@inf.bme.hu
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,8 +26,5 @@ typedef signed   char  sbyte;
 typedef unsigned short dbyte;
 typedef unsigned int   qbyte;
 
-typedef signed char    gchar;
-typedef signed short   gshort;
-typedef signed int     gint; 
-
 #endif /* Z80_TYPE_H */
+
